@@ -46,15 +46,14 @@ class callout:
         if not res['ok']:
             raise NLexTokenizerCreationException("Compile error")
         callout.download_url(compiler_server + '/download?file_id=' + res['file_id'], output_file + '.zip')
+        if os.path.exists(output_file): os.remove(output_file)
         with zipfile.ZipFile(output_file + '.zip', 'r') as f:
             try:
                 try:
                     f.extract('tokenizer.dll')
-                    os.remove(output_file)
                     os.rename('tokenizer.dll', output_file)
                 except:
                     f.extract('tokenizer.so')
-                    os.remove(output_file)
                     os.rename('tokenizer.so', output_file)
                 os.chmod(output_file, 0o755)
                 return os.path.realpath(output_file)
